# Pydori

[![PyPI version fury.io](https://badge.fury.io/py/pydori.svg)](https://pypi.python.org/pypi/pydori/)

A python package to interact with the bandori.party and bandori.ga public APIs.

# Info

# Installation
``` pip install pydori ```
# Example and Documentation

# Credits

[![PyPI license](https://img.shields.io/pypi/l/pydori.svg)](https://pypi.python.org/pypi/pydori/)

This project is licensed under the MIT license.

API provided by [bandori.party](https://bandori.party/) and [bandori database](https://bangdream.ga/).

I do not own any logos, images, or assets of the BanG Dream! Franchise, they are the property and trademark of Bushiroad. 